@@ -5,6 +5,7 @@ from traitlets import Bool, Unicode, CUnicode, List, Enum, observe, validate
 
 from . import geotraitlets
 from .locations import locations_to_list
+from .maps import GMapsWidgetMixin
 
 
 ALLOWED_TRAVEL_MODES = {'BICYCLING', 'DRIVING', 'TRANSIT', 'WALKING'}
@@ -15,7 +16,7 @@ class DirectionsServiceException(RuntimeError):
     pass
 
 
-class Directions(widgets.Widget):
+class Directions(GMapsWidgetMixin, widgets.Widget):
     """
     Directions layer.
 
@@ -73,9 +74,7 @@ class Directions(widgets.Widget):
     """
     has_bounds = True
     _view_name = Unicode("DirectionsLayerView").tag(sync=True)
-    _view_module = Unicode("jupyter-gmaps").tag(sync=True)
     _model_name = Unicode("DirectionsLayerModel").tag(sync=True)
-    _model_module = Unicode("jupyter-gmaps").tag(sync=True)
 
     data = List(minlen=2).tag(sync=True)
     data_bounds = List().tag(sync=True)
